@@ -1,16 +1,15 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.029-8-g78ff959
+package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.031-5-gad6e3a0
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Specify dynamic (user-side) prerequisites for your distribution
 # KEYWORDS: plugin distribution metadata MYMETA prerequisites Makefile.PL dynamic
 
-our $VERSION = '0.030';
+our $VERSION = '0.032';
 
 use Moose;
 with
     'Dist::Zilla::Role::FileGatherer',
-    'Dist::Zilla::Role::ModuleIncluder',
     'Dist::Zilla::Role::ModuleMetadata',
     'Dist::Zilla::Role::FileMunger',
     'Dist::Zilla::Role::MetaProvider',
@@ -65,12 +64,6 @@ has $_ => (
     default => sub { [] },
 ) foreach qw(include_subs conditions);
 
-# temporary workaround for broken Module::CoreList::is_core
-# (see https://rt.perl.org/rt3/Ticket/Display.html?id=128089)
-has '+include_dependencies' => (
-    default => 0,
-) if eval { Dist::Zilla::Role::ModuleIncluder->VERSION('0.005'); 1 };
-
 sub mvp_multivalue_args { qw(raw include_subs conditions) }
 
 sub mvp_aliases { +{
@@ -277,15 +270,18 @@ sub gather_files {
             $path = path('inc', $path . '.pm');
             my $cpath = $path->canonpath;
 
-            my $file = (first { $_->name eq $path or $_->name eq $cpath } @{ $self->zilla->files })
-                # TODO this requires a new release of ModuleIncluder
-                # || ($self->include_modules([ $module ], version->new('5.006001')))[0];
-                || do {
-                    $self->log([ 'inlining %s into inc/', $module ]);
-                    $self->include_modules([ $module ], version->new('5.006001'));
-                    first { $_->name eq $path or $_->name eq $cpath } @{ $self->zilla->files };
-                };
-            warn "failed to find $path in files" if not $file;
+            my $file = first { $_->name eq $path or $_->name eq $cpath } @{ $self->zilla->files };
+            if (not $file)
+            {
+                $self->log([ 'inlining %s into inc/', $module ]);
+                my $installed_filename = Module::Metadata->find_module_by_name($module)
+                    or $self->log_fatal([ 'Can\'t locate %s', $module ]);
+
+                $file = Dist::Zilla::File::OnDisk->new({ name => $installed_filename });
+                $file->name($path->stringify);
+                $self->add_file($file);
+            }
+            $self->log_fatal([ 'failed to find %s in files', $module ]) if not $file;
 
             if (defined $include_modules->{$module} and $include_modules->{$module} > 0)
             {
@@ -410,7 +406,7 @@ Dist::Zilla::Plugin::DynamicPrereqs - Specify dynamic (user-side) prerequisites
 
 =head1 VERSION
 
-version 0.030
+version 0.032
 
 =head1 SYNOPSIS
 
@@ -529,13 +525,13 @@ When combined with C<-raw>/C<-body> lines, the condition is placed first in a C<
 statement, and the C<-raw>/C<-body> lines are contained as the body of the block. For example:
 
     [DynamicPrereqs]
-    -condition = $] > '5.020'
+    -condition = "$]" > '5.020'
     -body = requires('1.003000')
 
 results in the F<Makefile.PL> snippet (note that whitespace is not added, in
 case this affects the parsing:
 
-    if ($] > '5.020') {
+    if ("$]" > '5.020') {
     requires('Role::Tiny', '1.003000')
     }
 
